# PTP IP Data Extractor

## Description

`ptp-ipdata-extractor` is a Python package for querying and extracting IP data with Kerberos authentication.
 It includes functions to retrieve IPs, query data, handle releases and reaching the latest data.
 this package is querying IBI DB, therefore authentication is required.

## Installation

You can install the package using pip:

```bash
pip install ptp-ipdata-extractor
 
